@@ -79,12 +79,6 @@ var LibraryPThreadStub = {
     return 0;
   },
 
-  pthread_self__asm: true,
-  pthread_self__sig: 'i',
-  pthread_self: function() {
-    return 0;
-  },
-
   pthread_attr_init: function(attr) {
     /* int pthread_attr_init(pthread_attr_t *attr); */
     //FIXME: should allocate a pthread_attr_t
@@ -110,6 +104,8 @@ var LibraryPThreadStub = {
     return 0;
   },
 
+  pthread_setcancelstate: function() { return 0; },
+
   pthread_once: function(ptr, func) {
     if (!_pthread_once.seen) _pthread_once.seen = {};
     if (ptr in _pthread_once.seen) return;
@@ -194,7 +190,10 @@ var LibraryPThreadStub = {
     return {{{ cDefine('EAGAIN') }}};
   },
   pthread_cancel: function() {},
-  pthread_exit: function() {},
+  pthread_exit__deps: ['exit'],
+  pthread_exit: function(status) {
+    _exit(status);
+  },
 
   pthread_equal: function() {},
   pthread_join: function() {},
@@ -338,6 +337,8 @@ var LibraryPThreadStub = {
   _emscripten_atomic_fetch_and_and_u64: '__atomic_fetch_and_8',
   _emscripten_atomic_fetch_and_or_u64: '__atomic_fetch_or_8',
   _emscripten_atomic_fetch_and_xor_u64: '__atomic_fetch_xor_8',
+
+  __wait: function() {},
 };
 
 mergeInto(LibraryManager.library, LibraryPThreadStub);
